@@ -112,14 +112,17 @@ class Data_inegrator:
 
                 epoch += 1
                 # Do an epoch on the training set.
-                for patient_train_batch in self.xy_train_dataloader:
-                    field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
-                    # If for some reason the batch has mor dimensions than expected, squeeze it.
-                    if len(field0_batch.shape) > 2:
-                        field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch[
-                            'FIELD1'].squeeze()
+                try:
+                    for patient_train_batch in self.xy_train_dataloader:
+                        field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
+                        # If for some reason the batch has mor dimensions than expected, squeeze it.
+                        if len(field0_batch.shape) > 2:
+                            field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch[
+                                'FIELD1'].squeeze()
 
-                    train_step_function(field0_batch, field1_batch)
+                        train_step_function(field0_batch, field1_batch)
+                except Exception:
+                    print('hi')
 
                 # Do validation
                 total_validation_loss_per_epoch = 0
