@@ -99,7 +99,7 @@ class patient_dataset(Dataset):
         for first_field in first_field_iterator:
             matching_couples.append((first_field, None))
         for second_field in second_field_iterator:
-            matching_couples.append(None,second_field)
+            matching_couples.append((None,second_field))
         return matching_couples
 
 
